@@ -45,20 +45,21 @@ class AlphaVantage(BaseSource):
             "You should obtain a free API key from "
             "https://www.alphavantage.co/support/#api-key and set it in "
             f"the {self.API_KEY_NAME} environment variable ({keystatus}), "
-            "otherise, pricehist will attempt to use a generic key.\n"
+            "otherwise, pricehist will attempt to use a generic key.\n"
             "The PAIR for currencies should be in BASE/QUOTE form. The quote "
             "symbol must always be for a physical currency. The --symbols option "
             "will list all digital and physical currency symbols.\n"
             "The PAIR for stocks is the stock symbol only. The quote currency "
             f"will be determined automatically. {self._stock_symbols_message()}\n"
-            "The price type 'adjclose' is only available for stocks.\n"
+            "The price type 'adjclose' is only available for stocks, and "
+            "requires an access key for which premium endpoints are unlocked.\n"
             "Beware that digital currencies quoted in non-USD currencies may "
             "be converted from USD data at one recent exchange rate rather "
             "than using historical rates.\n"
             "Alpha Vantage's standard API call frequency limits is 5 calls per "
             "minute and 500 per day, so you may need to pause between successive "
-            "commands. Note that retrieving prices for one stock requires two "
-            "calls."
+            "commands. Note that retrieving prices for one stock consumes two "
+            "API calls."
         )
 
     def _stock_symbols_message(self):
@@ -186,8 +187,13 @@ class AlphaVantage(BaseSource):
     def _stock_data(self, series):
         output_quote = self._stock_currency(series.base) or "UNKNOWN"
 
+        if series.type == "adjclose":
+            function = "TIME_SERIES_DAILY_ADJUSTED"
+        else:
+            function = "TIME_SERIES_DAILY"
+
         params = {
-            "function": "TIME_SERIES_DAILY_ADJUSTED",
+            "function": function,
             "symbol": series.base,
             "outputsize": self._outputsize(series.start),
             "apikey": self._apikey(),
@@ -225,7 +231,8 @@ class AlphaVantage(BaseSource):
                     "high": entries["2. high"],
                     "low": entries["3. low"],
                     "close": entries["4. close"],
-                    "adjclose": entries["5. adjusted close"],
+                    "adjclose": "5. adjusted close" in entries
+                    and entries["5. adjusted close"],
                 }
                 for day, entries in reversed(data["Time Series (Daily)"].items())
             }
@@ -332,6 +339,12 @@ class AlphaVantage(BaseSource):
         if type(data) == dict:
             if "Note" in data and "call frequency" in data["Note"]:
                 raise exceptions.RateLimit(data["Note"])
+            if (
+                "Information" in data
+                and "ways to unlock premium" in data["Information"]
+            ):
+                msg = "You were denied access to a premium endpoint."
+                raise exceptions.CredentialsError([self.API_KEY_NAME], self, msg)
             if "Error Message" in data and "apikey " in data["Error Message"]:
                 raise exceptions.CredentialsError([self.API_KEY_NAME], self)
 
